/**
 * The Butter class represents a meal that can be consumed by the kobold,
 * which increases its statuses.
 */
function Butter() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Butter";
    var itemDescription = "A stick of butter, wrapped in a preserving combination of paper and linen.";
    var baseValue = 10;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            Butter.
                            Churned milk.
                            Usually used as a spread to add flavor to bread, as a condiment, or as grease in a frying pan.
                            Sadly, you don't have the luxury of a stove, so you'll be eating yours as-is.
                        [/p]
                        [p]
                            You bring the stick of butter to your muzzle, and give it a little lick.
                            The taste is alright, but you aren't sure about eating the entire thing.
                            Still, if you just let it linger, it might spoil.
                            Suppressing the natural urge [b]not[/b] to shove pure [b]fat[/b] down your face, you take a large bite.
                        [/p]
                        [p]
                            The butter tastes surprisingly good.
                            It melts in your mouth like snow on a hot summer day, saturating your tastebuds with its slightly salty flavor.
                            While you [b]know[/b] this is bad for you, you swallow down and take a second bite, and then a third, and a fourth.
                            Before you regain your self-control, the entire stick of butter is gone, save for some of it stuck to your lips, which you eagerly lick clean.
                            Your guilty pleasure has left you in greater risk of heart conditions, but at least it was [i]somewhat[/i] nourishing.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.BUTTER;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 200px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.decrease(2, "Ate butter");
        global.kobold.status.mental.increase(2, "Ate butter");
        global.kobold.status.stamina.increase(2, "Ate butter");
        global.kobold.status.exertion.decrease(2, "Ate butter");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", -2), 
            new Change("Food", "Sanity", +2),
            new Change("Food", "Stamina", +2),
            new Change("Food", "Sexual exhaustion", -2, true)
        ]);
        global.ui.showFullscreenPopup(contents);
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
