/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodNothing(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.NOTHING;
    var reqController = ctrl.offer;
    var subController = ctrl.preGag;
    var changeController = ctrl.goodNothing;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, you won't gain the wolf's favor.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll undoubtedly lead to him asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            You don't want that.
                        [/p]
                        [p]
                            You find yourself locked in mental conflict,
                            internally debating on whether or not you should accept the wolf's offer.
                            The question the canine has posed is not an easy one.
                            Ultimately, it boils down to whether you want to please him,
                            and keep him as a friend,
                            or if you'd rather take your chances going at this alone.
                            The thing is: you don't know whether or not you [i]want[/i] a friend like Fenrir.
                            Especially not at the cost of your own pride.
                        [/p]
                        [p]
                            Why couldn't he have just grabbed your head and shoved you into his nuts?!
                            That would have made things [b]so[/b] much easier.
                            That way, your body and your natural instincts could have made this decision for you.
                            Fenrir seems to be getting impatient, but you haven't reached a conclusion yet.
                            Part of you wants to submit.
                            You're scared of what might happen if you don't.
                            But doing this means forsaking whatever dignity you have left.
                            And you can't do that.
                            Not out of your own volition, at least.
                        [/p]
                        [p]
                            You fail to heed the lupine's request.
                            The look on his face transitions rapidly from boredom, to anger, to something resembling a lack of understanding.
                            Finally, he settles on a sadistic grin, probably trying to hide his true feelings.
                            "[color=gblue]Not going to do it, huh?
                            Suit yourself.
                            This was a one time offer, and a good one at that.
                            If you're [b]lucky[/b], I might see fit to ask you again later.
                            But a little [i]kiss[/i] won't suffice next time.[/color]"
                            His words worry you far more than they should.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
