/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodPotion(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preGag;
    var subController = ctrl.potion;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new SlaveNoonTwoGoodNeither(ctrl);
    var secondNext = new SlaveNoonTwoGoodMPlus(ctrl);
    var thirdNext = new SlaveNoonTwoGoodFemPlus(ctrl);

    var firstChoice = SlaveNoonTwoGoodPotionChoice.NEITHER;
    var secondChoice = SlaveNoonTwoGoodPotionChoice.MPLUS;
    var thirdChoice = SlaveNoonTwoGoodPotionChoice.FEMPLUS;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Your private business concluded,
                            the wolf crudely grabs you by the wrist, and begins to tug you towards the cart's open entryway.
                            "[color=gblue]You and I have business to attend to.
                            In case you hadn't realized yet: you're being [b]sold[/b].
                            [b]Today[/b].
                            And it's [b]my[/b] job to ensure you look at least [i]somewhat[/i] presentable.[/color]"
                        [/p]
                        [p]
                            He's not taking [i]no[/i] for an answer,
                            yanking you forwards hard enough to nearly pull your arm off.
                            Guess he's in a rush, despite wasting time with his [i]proposition[/i].
                            You don't resist much, instead trying to keep up with his pace as best you can.
                            A few steps and a small hop later, you find yourself in the outside world once more.
                        [/p]`;

        if (ctrl.arrival.get() !== SlaveNoonTwoArrivalChoice.LOOKOUT) {
            toReturn += `[p]
                            You recognize this area.
                            You've been here before.
                            It's a place known simply as [i]the hamlet[/i],
                            a small village close to the human capital of Varanar.
                        [/p]
                        [p]
                            An old friend of yours lives here.
                            Seki, the alchemist-owl, who also happens to happily buy whatever stolen goods you bring him.
                            Besides being your [i]fence[/i], he's also the closest thing to a [i]father[/i] you've ever had.
                            Maybe [b]he[/b] can help you get out of this [b]mess[/b].
                        [/p]`;
        }

        toReturn += `   [p]
                            Luckily, the caravan stopped at the outskirts of the settlement,
                            your nudity not made public quite yet.
                            If it's any [i]consolation[/i], your captor is every bit as naked as you are.
                            Walking alongside your prison carriage's exterior,
                            whilst dragging you with him, the canine comes to an unexpected halt,
                            your face ending up unpleasantly [i]bumping[/i] into his bare rear.
                            Reaching down, he fetches a small, brown satchel, conveniently concealed directly underneath the cart.
                        [/p]
                        [p]
                            "[color=gblue]I almost forgot.
                            I've prepared a [i]treat[/i] for you.
                            A little [b]present[/b], to help your odds at the auction.
                            I have no doubt you'll be making back every coin I spent on these and more.[/color]"
                            You don't know whether you should feel [i]flattered[/i], or [b]insulted[/b].
                            "[color=gblue]If not through being auctioned off,
                            then through all the gold I'll be saving from fucking you instead of visiting a brothel.[/color]"
                            Definitely [b]${eager ? `flattered` : `insulted`}[/b].
                        [/p]
                        [p]
                            Rummaging through the tiny bag, Fenrir produces a pair of oddly shaped bottles, along with a large, ominous-looking syringe.
                            ${global.kobold.inventory.createItemWithTooltip(new FemPlus(), true)}
                            and ${global.kobold.inventory.createItemWithTooltip(new mPlus(), true)}.
                            Seki makes that sort of stuff.
                            "[color=gblue]Well, here they are.
                            These things are expensive,
                            so you only get [b]one[/b].
                            Well, ${name}, which'll it be?
                            The blue one, or the pink one?[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Neither</button>`;

        var tooltip = global.parser.parse(`You don't need to change.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>mPlus</button>`;

        var tooltip = global.parser.parse(`Maybe you could stand to be a bit more [i]masculine[/i].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>FemPlus</button>`;

        var tooltip = global.parser.parse(`The more girly, the better.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var SlaveNoonTwoGoodPotionChoice = {
    NEITHER: 1,
    MPLUS: 2,
    FEMPLUS: 3
};
