/**
 * Hide section of the woods.
 * @param {ForestController} controller The Forest controller.
 */
function ForestWoodsRunSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new ForestWoodsRunSucceedContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Your very life at stake, you line yourself up perfectly with the piece of wood blocking your path.
                            You're only going to get [b]one[/b] shot at this.
                            Succeed, and you can escape through the copse, and hopefully make it home by nightfall.
                            If you fail, the wolf'll catch up to you, and who knows what he'll do?
                        [/p]`;

        if (ctrl.run.get() === ForestWoodsRunChoice.BREAKTHROUGH) {
            toReturn += `[p]
                            You [b]storm[/b] towards the barring branch,
                            digging your claws into the dirt below to add an extra ounce of sheer [b]power[/b] to your barreling form.
                            Gritting your teeth, you [b]ram[/b] into the wooden barricade with [b]all[/b] of your might.
                            With a loud [b]crack[/b], the rotten branch breaks in half, clearing a path into the heart of the thicket.
                            You disappear into the maze of trees with not a moment to spare, leaving the wolf to curse his broad build.
                        [/p]
                        ${global.ui.condSucc(`Strength greater than 5`)}`;
        } else {
            toReturn += `[p]
                            You [b]rush[/b] towards the barring branch,
                            eyeing the small clearance below it, envisioning yourself sliding underneath it and emerging safely on the other side. 
                            Waiting until the very last moment, you let your upper body drop to the ground, gliding feet-first underneath the barricade.
                            To your own surprise, you make it to the other side with a scratch!
                            After getting back up on your feet, you disappear into the maze of trees with not a moment to spare, leaving the wolf to wonder where you went.
                        [/p]
                        ${global.ui.condSucc(`Agility greater than 5`)}`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.preContinue.continued() ? "disabled" : "";
        var isSelected = ctrl.preContinue.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.preContinue.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.runSucceed.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        next.registerListeners();

        if (ctrl.preContinue.continued()) {
            return;
        }

        registerNextListener();
    };
}
