/**
 * Barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnTeaDisagreeContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "notBarnTeaDisagreeContinueButton";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var int = ctrl.misc.intelligence();
        var cha = ctrl.misc.charisma();
        var toReturn = `[p]
                            Cassidy wishes you a good day,
                            the last thing you see of the vixen being the wide, smug grin plastered across her face as she closes the door behind you.
                            You are left standing in the cold, feeling utterly distraught,
                            doubting the very [i]right[/i] of your entire [b]race[/b] to exist outside of the confines of animal enclosures and cages.
                            Perhaps it [i]would[/i] be a good thing for kobolds to be [i]domesticated[/i] by a more [i]civil[/i] species.
                        [/p]
                        [p]
                            Even [b]you[/b] are, after all, nothing but a [b]thief[/b].
                            A negative influence on society as a whole.
                            A leech.
                            Perhaps you'd be better off being some rich nobleman's [i]pet[/i].
                            At least then you wouldn't have to worry about getting [b]hunted down[/b] by people aiming to collect the money you owe.
                        [/p]
                        [p]
                            With a resigning sigh, you walk back to the center of the hamlet.
                            After pondering the debate for a few more minutes, questioning the merits of your own freedom,
                            you decide to put the entire ordeal behind you, at least for now.
                            If you [b]truly[/b] still feel like you shouldn't be in charge of your own life, for your own sake,
                            you can always start looking for a family in need of a [b]pet[/b] [i]after[/i] you settle your debt.
                            Heck, maybe you'll even find your way back to Cassidy.
                            [i]Maybe[/i].
                        [/p]
                        [p]
                            You decide it's time to head for Varanar.
                            It's already late in the afternoon, and the sun tends to set rather early during the winter.
                            Even this close to the capital of the humans, the roads [b]aren't[/b] safe at night.
                            Especially not for an ownerless pet like yourself.
                        [/p]`;

        if (int >= 6 && cha >= 6) {
            toReturn = `[p]
                            Cassidy wishes you a good day,
                            the last thing you see of the vixen being a confused, pensive look plastered across her face as she closes the door behind you.
                            You are left standing in the cold, feeling equally confused,
                            doubting the very [i]right[/i] of your entire [b]race[/b] to exist outside of the confines of animal enclosures and cages.
                            Still, you are convinced it would [b]not[/b] be a good thing for kobolds to be [i]domesticated[/i] by another species.
                        [/p]
                        [p]
                            With a soft, self-inspiring grunt, you walk back to the center of the hamlet.
                            You ponder the debate for a few more minutes, questioning the merits of your entire kind.
                            The vixen thinks kobolds are nothing more than thieves, bandits and other lowlife scum, but you [b]can[/b] and you [b]will[/b] prove her wrong.
                            Just because kobolds have never achieved greatness before doesn't mean that they –- that [b]you[/b] -- never will!
                        [/p]
                        [p]
                            If you want to become the best kobold you can be, if just to prove Cassidy wrong, then you need to get started as soon as you can.
                            You decide it's time to head for Varanar.
                            It's already late in the afternoon, and the sun tends to set rather early during the winter.
                            Even this close to the capital of the humans, the roads [b]aren't[/b] safe at night.
                            And you doubt bandits care whether or not you're trying to get your life back on track.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnTeaDisagreeContinue";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.postnotbarn.continued()) {
            return "";
        }

        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.teaDisagreeContinueChange();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.postnotbarn.continued()) {
            return;
        }

        //toEager.registerListeners();

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}
