/**
 * Steal section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseShedNoWeapon(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    
    var continueId = arguments.callee.name + "ButtonOne";
    var next = new FarmerHouseShedRun(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.misc.weapon();
        var toReturn = `[p]
                            You decide against taking a pitchfork as your weapon.
                            ${weapon ? `You already have a perfectly fine ${global.kobold.inventory.createItemWithTooltip(weapon)} anyway.` : ``}
                            Still, you aren't going to walk away from this entire ordeal empty-handed.
                            You don't want to have risked trespassing with absolutely [b]nothing[/b] to show for it.
                            You need [i]something[i], [b]anything[/b] to make it seem like you [b]didn't[/b] waste your time coming here.
                        [/p]
                        [p]
                            While most of the tools are neatly arrayed on a small table or hanging off the wall on half-crooked nails,
                            there's a metallic pile of rusty [b]rubbish[/b] cluttering a corner of the shed that you had neglected at first.
                            Seeing as everything else is practically worthless, you may as well look through it and see if there's anything of any value.
                        [/p]
                        [p]
                            You drop to your knees, and begin to rummage through the pile of metallic scrap.
                            After removing a few rusted pieces, you see a small glint of something shiny at the very bottom of the heap.
                            Excited, you eagerly reach for what you [b]hope[/b] to be a pile of coins buried underneath the rest of the trash,
                            yet long before you manage to make it to the object in question,
                            your hand brushes alongside an exceptionally [b]sharp[/b] piece of metal, which [b]rakes[/b] open your tender palm.
                        [/p]
                        [p]
                            You barely refrain from [b]screaming[/b] in pain.
                            You use your free hand to cover your muzzle, silencing the few pathetic whimpers that escape your lips.
                            You slowly retract the bleeding appendage from the pile of metal refuse, careful not to bump into any other jagged edges.
                            Blood leaks liberally from it, dripping down on top of the rusted heap, obscuring the glint that had caught your attention,
                            burying it, along with your self-esteem.
                        [/p]
                        [p]
                            Once fully removed from the scrapheap, you inspect the damage done to your palm, clutching your wrist with your free hand.
                            The cut is luckily not very [b]deep[/b], but it [b]is[/b] pretty long, 
                            running from the top of your wrist along the entire length of your palm, stopping just short of your index finger.
                            Despite it being shallow, your wound [b]hurts[/b] like [b]hell[/b], and it's bleeding quite a lot.
                        [/p]
                        [p]
                            You sit yourself down on the dusty wooden floor.
                            A few tears spill from your eyes.
                            You try to remain stoic, yet the pain mixed with the humiliation of utter [b]failure[/b] are too much.
                            That shiny thing you saw probably wasn't even a coin.
                            You quietly begin to sob.
                        [/p]
                        [p]
                            You're a thief, yet that's [b]twice[/b] now that you've completely [b]fucked up[/b] stealing from these simple farmers,
                            some of which have a life worse than your own.
                            Although right now, you find that a bit hard to believe.
                            As the bleeding slowly comes to a halt, you painfully wriggle your fingers around to make sure nothing critical was damaged.
                            Through teary eyes, you observe that all four of them are still in working condition,
                            although it'll be a while still before you can move them without hurting yourself.
                        [/p]
                        [p]
                            This is all that stupid farmer's fault.
                            If he had some [b]decent[/b] tools, you wouldn't have had to go rummaging in his pile of [b]crap[/b].
                            Why does he keep rusted metal around anyway?!
                            Stupid human.
                        [/p]
                        [p]
                            You rise to your feet once more.
                            You wipe your eyes with your non-hurting hand.
                            Your tears have stopped, but your dignity remains dented.
                            You have been bested by a pile of scrap.
                            You [i]want[/i] to kick it, to get some [i]revenge[/i] on the inanimate objects that hurt you,
                            but you'd rather not draw attention, let alone cut your foot as well.
                            With a hurting hand and wounded pride, you decide to leave the shed.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.postshed.continued() ? "disabled" : "";
        var isSelected = ctrl.postshed.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.postshed.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if(ctrl.shed.get() !== FarmerHouseShedChoice.NOWEAPON) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.postshed.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if(ctrl.shed.get() !== FarmerHouseShedChoice.NOWEAPON) {
            return;
        }
        
        next.registerListeners();

        if (ctrl.postshed.continued()) {
            return;
        }

        registerNextListener();
    };
}
