/**
 * Arrival section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = ctrl.arrival;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.surface;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var drowned = global.kobold.history.shared.well.drowned;
        var toReturn = `[p]
                            You keep moving forwards through the tiny, cramped tunnel flooded with water,
                            your motions more akin to [b]crawling[/b] than swimming.
                            The shaft is far too small for you to practice any proper swimming strokes.
                            You end up digging the claws of both your hands and your feet into the submerged,
                            muddy dirt surrounding you on all sides, using it to propel you forwards, to clamber onwards.
                        [/p]
                        [p]
                            While the well was dark, there was still [i]some[/i] natural light shining in from the hole at the top.
                            No such luck here.
                            In the submerged pitch-blackness of these claustrophobic depths, not even your perfect night-sight can distinguish rock from mud.
                            Not that you [i]need[/i] to see much.
                            There's only one way to go.
                            And if your head bumps into something, you'll know you've reached the end, of not only the tunnel, but of your life.
                        [/p]
                        [p]
                            You crawl onwards for nearly an entire minute,
                            driven only by the will to live and the fading hope that there will be light at the end of the tunnel.
                            Your lungs ache.
                            They burn, desperately in [b]need[/b] of fresh air${drowned ? ", a feeling you are not entirely unfamiliar with" : ""}.
                            Moving is getting harder.
                            Your limbs begin to slow down.
                            Your extremities grow numb.
                            Your consciousness is fading.
                            The tunnel is widening.
                            Just a little further.
                        [/p]
                        [hl]
                        [p]
                            With a loud [b]splash[/b], you emerge from the water,
                            your half-gone mind barely even [b]registering[/b] the fact that you can breathe once more.
                            Through basic survival instinct, and nothing else, you take a first, small breath,
                            the tiniest sliver of oxygen breathing new life into your fading form.
                            Your eyes shoot open, greeted by the scarcely illuminated sight of a rock-hewn cave,
                            no doubt carved out by the elongated body of water you find yourself in.
                        [/p]
                        [p]
                            But where exactly you are is a concern for later.
                            For now, you greedily gulp down the precious gift of air, savoring it like a fine meal after being starved for [b]months[/b] on end.
                            It fans the flickering flame of your very existence, a fire which came [b]very[/b] close to being extinguished for good.
                            Feeling very lightheaded, like you might pass out still, you meekly swim to the water's stony edge,
                            and with your last ounce of energy, you pull yourself from the liquid, onto dry land.
                            Once secured on the stony cavern floor, your overexerted body collapses, and your weary mind slips into unconsciousness.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.applyTheme("hamlet_cave");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
