/**
 * Reflect section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveReflectionPetrify(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = UndergroundCaveReflectionSucceedChoice.PETRIFY;
    var reqController = ctrl.reflectSucceed;
    var setChoice = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.reflectPetrify;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveReflectionPetrifyContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Seeing an opportunity for greatness, you press your advantage.
                            You hold the mirror shard directly in front of the basilisk's eyes, [b]forcing[/b] it to stare at its own enchanting gaze.
                            You could probably just [b]rake open[/b] its throat instead, but you kind of [i]like[/i] turning its own weapon against the beast.
                            The creature tries to look away, but after a few seconds, its own alluring reflection captures its sight.
                            It lets out another whine, audibly scared.
                            This is clearly not what it expected – or hoped – to happen.
                        [/p]
                        [p]
                            The big reptile is too weak to resist now.
                            Too far gone already.
                            Its breathing grows slower, weaker.
                            Its flicking tongue grows limp.
                            Its bestial snout locks in place.
                            Its rocky scales lose whatever color they had, and the muscles underneath them stop moving.
                            Finally, as its breathing comes to a complete halt, its very eyes turn to stone, and then you know it is over.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    You have killed the basilisk.
                                [/b]
                            [/c]
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            setChoice ? subController.set(setChoice) : subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
