/**
 * Wake up section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeRefuseWakeUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Your sleep is troubled by [i]nightmares[/i], 
                            your mind subconsciously re-living the awful, scary moments of the passed day over and over again.
                            You toss and turn in your [i]bed[/i], until finally, at the break of dawn, you awake from your slumber,
                            finding yourself resting on the cold, dirt floor instead of in the warm embrace of hay.
                        [/p]
                        [p]
                            You let out an annoyed moan as you rise to your feet.
                            While you slept like shit, at least your jaw is feeling a bit better.
                            On the other hand, your body is feeling a bit [i]stiff[/i] from sleeping on the ground.
                            But you don't let that stop you from going out the door.
                            As you leave your home, you are immediately greeted by a gust of fresh morning air,
                            which does wonders to wipe away your budding morning-grumpiness.
                        [/p]
                        [p]
                            With your mind cleared, you think about the future for a moment.
                            You still owe the Three-Tailed Rat about fifty gold, a sum which you're certain he won't just forget about.
                            You take in a deep breath, and decide that the best course of action for you to take would be to head for Varanar,
                            although you could take a small detour and visit the tiny hamlet right outside the city limits first.
                            Whichever route you choose, you hope you'll end [i]this[/i] day with a better nap than the one you just woke up from.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeRefuseWakeUp";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.debt.firstSegmentContinued()) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.saved.debt.refuseWakeChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.debt.firstSegmentContinued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}
