/**
 * Pillaged section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomePillaged(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Your home may be pillaged, but that doesn't mean you can't still sleep in it.
                            Whoever raided your place is probably long-gone.
                            Sticking around a seemingly abandoned hovel would be meaningless for them,
                            and nobody's going to come looking for you while it's dark out.
                        [/p]
                        [p]
                            Having mentally reassured yourself that everything will be just fine, you walk up to the front-end of your shed.
                            You try to open the busted door, but to your annoyance, this causes it to fall off of its hinges completely, 
                            tumbling down against the wooden back-wall of your home, nearly taking the entire ramshackle thing down with it.
                        [/p]
                        [p]`;

        var male = ctrl.gender() === GenderEnum.MALE;
        if (male) {
            toReturn += `   You let out a loud sigh.
                            Stepping inside, over the remains of the entryway, you use your masculine strength to lift up the door.
                            It's human-sized, but that doesn't stop you from putting it back onto its hinges.
                        [/p]
                        [p]
                            Slightly inspired by your own prowess, `;
        } else {
            toReturn += `   You let out a loud sigh.
                            Stepping inside, over the remains of the entryway, you try, but fail to lift up your door.
                            It's human-sized, making it far too heavy for someone of your posture to properly handle.
                        [/p]
                        [p]
                            Slightly disheartened, `;
        }

        toReturn += `       you begin to collect the scattered remains of the bale of hay that you call your [i]bed[/i].
                            Those [b]savages[/b] completely [b]tore[/b] it apart, probably thinking you had some valuables concealed within.
                            You almost feel like a bird making a nest.
                            It takes a couple of minutes, but you eventually manage to form a small pile of straw, big enough for you to sleep on.
                        [/p]
                        [p]
                            You lie down on top of the warm, comfortable former-fodder.`;

        if (male) {
            toReturn += `   The hay, together with your fixed door, provide for a warm and snug environment.`;
        } else {
            toReturn += `   The hay shields you from the cold seeping in through the busted door.`;
        }

        toReturn += `       Due to sheer exhaustion, you manage to drift to sleep rather quickly.
                        [/p]
                        [p]
                            ${male ? "Thanks to your fixed door," : "Despite your door being broken,"} you end up having a nice, if brief, little nap.
                            You slowly wake up hours later, completely [b]buried[/b] in the pile of straw, your scaly body being nurtured by the lingering warmth it provides.
                            While you'd love to stay and rest for just a bit longer, dawn is breaking.
                            You were right about people [i]not[/i] looking for you during the night, but you don't want to risk sticking around during daytime.
                        [/p]
                        [p]
                            You rise from your nest feeling quite rejuvinated.
                            Your short slumber did you good.
                            It allowed your brain and your body both to recover significantly.
                            You are ready to put the trials and tribulations of yesterday aside, and do whatever you need to do to make it through another day.
                        [/p]
                        [p]
                            You step out of the ${male ? "fixed" : "busted"} door, and are instantly greeted with a gust of cool morning air.
                            You breathe in deeply, clearing your mind before thinking about the future.`;

        var gold = ctrl.gold();
        if (!gold) {
            toReturn += `   You are completely [b]broke[/b]. 
                            You have no money whatsoever to pay your overdue debts with.
                            Desperate times call for desperate measures.`;
        } else if (gold > 150) {
            toReturn += `   You have quite a bit of money, but sadly it's still not enough to pay your overdue debt.`;
        } else if (gold > 203) {
            toReturn += `   You have [b]a lot[/b] of money, more than you gained from just robbing the caravan, even.
                            You're [b]very[/b] close to being able to pay off your debt.
                            You just need a [i]teensy[/i] bit more.
                            But you aren't going to get it from these woods.`;
        }

        toReturn += `       You decide to head out, to seek your fortune in the great city of Varanar,
                            and maybe take a stop at the small hamlet outside of the city walls along the way.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homePillaged";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unsaved.getSleepChoice() !== HomeUnsavedChoice.INSIDE) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.unsaved.pillageChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unsaved.getSleepChoice() !== HomeUnsavedChoice.INSIDE) {
            return;
        }

        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}
