/**
 * Arrival section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorEntrance(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.arrival;
    var subController = ctrl.entrance;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";

    var firstNext = ctrl.fragments.decline;
    var secondNext = ctrl.fragments.noGold;
    var thirdNext = ctrl.fragments.accept;
    var fourthNext = new AfternoonThreeParlorBarter(ctrl);

    var firstChoice = AfternoonThreeParlorEntranceChoice.DECLINE;
    var secondChoice = AfternoonThreeParlorEntranceChoice.NOGOLD;
    var thirdChoice = AfternoonThreeParlorEntranceChoice.ACCEPT;
    var fourthChoice = AfternoonThreeParlorEntranceChoice.BARTER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        ctrl.misc.weapon(); // Caching
        ctrl.misc.hasAnything(); // Caching
        global.kobold.history.shared.varanar.dayThree.afternoon.massageParlor = true;
        var clothes = !ctrl.misc.nude();
        var gold = ctrl.misc.gold();
        var toReturn = `[st]Massage parlor[/st]
                        [p]
                            The interior is surprisingly ornate for an otherwise dilapidated structure.
                            It's also far bigger than it appeared from the outside.
                            The room you're standing in looks like a [i]lobby[/i] of sorts.
                            Behind a wooden desk sits a large, bearded, bald human, too engrossed in reading a note to notice your arrival.
                            He is clad in poor attire, his clothing riddled with holes and tears.
                            Almost looks like a burlap sack he cut arm and leg-holes into!
                            His skin is [b]extremely[/b] pale, and while you're no expert on humans, he doesn't seem like a very healthy fellow.
                        [/p]
                        [p]
                            From where you're standing, you can see at least two other rooms through open doorways. 
                            There's a work room, with an orange-scaled kobold tidying up a series of massaging tables,
                            and what you presume to be a break room containing three other members of your kind, lounging about.
                            Red, green like yourself and blue.
                            Quite the collection of colors!
                        [/p]
                        [p]
                            After several moments, the man looks up and notices you.
                            He eyes you up and down, silently [i]judging[/i] you before speaking.
                            "[color=purple]Welcome to the Kobold's Den.[/color]" 
                            His voice is deep, his tone is firm, and he carries himself as a man who is used to getting his way,
                            despite his half-sickly appearance.
                            You see him reach for something under the desk, but you can't tell what it is from your vantage point.
                        [/p]
                        [p]
                            "[color=purple]I'm [b]Tychus[/b], the owner of this [i]fine establishment[/i].[/color]"
                            You sense of a hint of sarcasm in his voice.
                            Self-deprecation must be a favored pastime for anyone living in [i]smelltown[/i].
                            You ask him if you were right in assuming this is a massage parlor employing kobolds.
                            A smirk forms on his face.
                            "[color=purple]Was the sign not clear enough for you?[/color]"
                            It was pretty hard to make out, you confess.
                            "[color=purple]It's the best I could afford since my previous business went under.
                            And that also explains why I had to hire [i]your[/i] kind.[/color]"
                            Yikes.
                        [/p]
                        [p]
                            "[color=purple]This is the only massage parlor in town that employs kobolds.
                            It seems that I've finally found something you little lizards are actually [i]good[/i] at, besides whoring yourselves out.
                            Your little hands are [b]far[/b] more nimble than human palms,
                            and they lack fur that gets all sticky when mixed with massage oil.
                            Plus some of my more [i]hardy[/i] customers enjoy a good clawed backscratching.
                            I'd say dragonesses are better masseuses, but I can't afford those.[/color]"
                        [/p]
                        [p]
                            Unsure how to react, you walk up to the man's desk.
                            You [i]guess[/i] he's somehow [i]complimenting[/i] you?
                            Luckily, he himself breaks the awkward silence that falls between the two of you.
                            "[color=purple]Anyway, I don't suppose you're here for a job.
                            So, how about a massage instead?[/color]"
                        [/p]
                        [p]
                            You get the distinct feeling that something isn't right here, but you can't quite put your finger on [i]what[/i] is wrong.
                            Perhaps there's just something unsettling about talking to a human [i]without[/i] him insulting and berating you.
                            Tychus takes your hesitation for confusion.
                            "[color=purple]Let me explain a bit more.
                            You pay me forty coins, and then you get an hour-long massage from one of my girls.[/color]"
                            You mention that one of his [i]workers[/i] is clearly a [b]boy[/b].
                            "[color=purple][b]All[/b] you kobolds are [b]girls[/b] compared to us humans.[/color]"
                            There's the talking down you're used to.
                        [/p]
                        [p]
                            "[color=purple]You pay up front,
                            ${clothes ? `you take off your clothes,
                            and you head to the back room.
                            It's not like you kobolds are often dressed.` : `you're already naked,
                            as you kobolds often are,
                            so no need to worry about taking off your clothes.
                            You can head straight to the backroom, [b]after[/b] paying.`}
                            So, what do you say?
                            Want to feel good, for [b]once[/b] in your miserable life?
                            Or will you keep feeling like the [b]loser[/b] you are?[/color]"
                        [/p]
                        [p]
                            His sales pitch took a turn for the worse,
                            ending up almost outright [b]insulting[/b] you instead of praising his workers,
                            but you have to admit that Tychus [b]is[/b] kind of [i]right[/i].
                            It [b]would[/b] be nice to relax, if only for an hour.
                            forty coins is a steep price, though.
                            ${gold > 39 ? `You can afford it, but it's a [b]lot[/b] of money.` : `You can't even afford it.`}
                            And while Tychus has started to speak a bit more [i]human-like[/i],
                            you still think there's something [i]off[/i] about him.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Decline</button>`;

        var tooltip = global.parser.parse(`No thanks, you don't really want a massage. Especially not at [i]that[/i] rate.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var failedCheck = ctrl.misc.gold() > 39;
        var disabled = subController.has() || failedCheck ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>No gold</button>`;

        var tooltip = global.parser.parse(`You can't really afford that.`);
        if (failedCheck) {
            tooltip = global.parser.parse(`You [b]do[/b] have enough money.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var failedCheck = ctrl.misc.gold() < 40;
        var disabled = subController.has() || failedCheck ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Accept</button>`;

        var tooltip = global.parser.parse(`You could really use a massage, even at an exorbitant price.`);
        if (failedCheck) {
            tooltip = global.parser.parse(`You don't have enough money for this.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled}>Barter</button>`;

        var tooltip = global.parser.parse(`Attempt to barter the human down to a more reasonable price.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 10px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildThirdChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFourthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId), $("#" + fourthId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("hamlet_barn");
        ctrl.bgm.loop();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        if (ctrl.entrance.get() !== AfternoonThreeParlorEntranceChoice.BARTER) {
            part += firstNext.build();
            part += secondNext.build();
            part += thirdNext.build();
        }
        part += fourthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.entrance.get() !== AfternoonThreeParlorEntranceChoice.BARTER) {
            firstNext.registerListeners();
            secondNext.registerListeners();
            thirdNext.registerListeners();
        }
        fourthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
    };
}

var AfternoonThreeParlorEntranceChoice = {
    DECLINE: 1,
    NOGOLD: 2,
    ACCEPT: 3,
    BARTER: 4
};
