/**
 * End section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEatLeave(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenEatChoice.LEAVE;
    var reqController = ctrl.eat;
    var changeController = ctrl.eatLeave;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You don't really know how to [i]console[/i] him,
                            so you settle for thanking the man for the food.
                            You feel better now.
                            A [b]lot[/b] better.
                            You're certain his wife is proud of him, wherever she may be.
                        [/p]
                        [p]
                            The man sighs.
                            "[color=ppink]Aye, aye.
                            Ah tried me hardest.
                            'Ave yeh finished yer meal?[/color]"
                            You nod.
                            "[color=ppink]Ah hate tah be rude, but could yeh maybe see yerself out?
                            Ah think ah need a moment alone.
                            To mahself.[/color]"
                            You say you understand, but you obviously don't.
                        [/p]
                        [p]
                            Getting up off your seat, you solemnly walk out the building the way you came.
                            Closing the door behind you, you let out an exasperated sigh.
                            That poor man.
                            The outside air is as cold as your heart felt when walking out on him.
                            But there's nothing you can do to help.
                            You've got your own issues to worry about.
                            While you [b]wish[/b] you were some kind of [b]hero[/b] or a [b]knight[/b],
                            you simply don't have the time or the resources to aid everyone in Varanar.
                        [/p]
                        [p]
                            Swallowing deeply, you set aside your empathetic sadness.
                            To take your mind off of trying to appease dead relatives,
                            you decide to take a stroll down the grand avenue.
                            None of the stores were open last night, but this time around,
                            you're certain there'll be at least [b]one[/b] shop able to pull your mind away from gloomy thoughts.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
